package
Version:
v0.0.0-...-6879cb0
Opens a new window with list of versions in this module.
Published: Mar 22, 2024
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Meme struct {
ID uuid.UUID `json:"id"`
Text string `json:"text,omitempty"`
URL string `json:"url,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.